==> ejc-probid-impl-3.0.0-20220715.082857-6-sources.jar: com/ejianc/business/record/controller/RecordController.java <==
package com.ejianc.business.record.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.record.bean.RecordEntity;
import com.ejianc.business.record.service.IRecordService;
import com.ejianc.business.record.vo.RecordVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 工程投标备案实体
 *
 * @author generator
 */
@RestController
@RequestMapping("record")
public class RecordController implements Serializable {
	private static final long serialVersionUID = -8218768849910542504L;

	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	private static final String RULE_CODE = "PROBID_RECORD";
	private static final String BILL_CODE = "EJCBT202207000013";
	private final IBillTypeApi billTypeApi;
	private final IBillCodeApi billCodeApi;
	private final IOrgApi iOrgApi;
	private final IRecordService service;
	private final SessionManager sessionManager;

	public RecordController(IBillTypeApi billTypeApi, IBillCodeApi billCodeApi, IOrgApi iOrgApi, IRecordService service, SessionManager sessionManager) {
		this.billTypeApi = billTypeApi;
		this.billCodeApi = billCodeApi;
		this.iOrgApi = iOrgApi;
		this.service = service;
		this.sessionManager = sessionManager;
	}

	/**
	 * @Description saveOrUpdate 新增或者修改
	 */
	@PostMapping(value = "/saveOrUpdate")
	public CommonResponse<RecordVO> saveOrUpdate(@RequestBody RecordVO saveOrUpdateVO) {
		RecordEntity entity = BeanMapper.map(saveOrUpdateVO, RecordEntity.class);
		if (entity.getId() == null || entity.getId() == 0) {
			BillCodeParam billCodeParam = BillCodeParam.build(RULE_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
			CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
			if (billCode.isSuccess()) {
				entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
			} else {
				throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
			}
		}
		service.saveOrUpdate(entity, false);
		RecordVO vo = BeanMapper.map(entity, RecordVO.class);
		return CommonResponse.success("保存或修改单据成功！", vo);
	}

	/**
	 * @param id
	 *
	 * @Description queryDetail 查询详情
	 */
	@GetMapping(value = "/queryDetail")
	public CommonResponse<RecordVO> queryDetail(Long id) {
		RecordEntity entity = service.selectById(id);
		RecordVO vo = BeanMapper.map(entity, RecordVO.class);
		return CommonResponse.success("查询详情数据成功！", vo);
	}

	/**
	 * @Description delete 批量删除单据
	 * @Param [ids]
	 */
	@PostMapping(value = "/delete")
	public CommonResponse<String> delete(@RequestBody List<RecordVO> vos) {
		if (ListUtil.isNotEmpty(vos)) {
			for (RecordVO vo : vos) {
				// 参数是单据类型编码字符串 根据需求是否打开下面代码
				CommonResponse<String> resp = billTypeApi.checkQuote(BILL_CODE, vo.getId());
				if (!resp.isSuccess()) {
					return CommonResponse.error("删除失败！" + resp.getMsg());
				}
			}
		}
		service.removeByIds(vos.stream().map(RecordVO::getId).collect(Collectors.toList()), true);
		return CommonResponse.success("删除成功！");
	}

	/**
	 * @param param
	 *
	 * @Description queryList 查询列表
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
	 */
	@PostMapping(value = "/queryList")
	public CommonResponse<IPage<RecordVO>> queryList(@RequestBody QueryParam param) {

		List<String> fuzzyFields = param.getFuzzyFields();
		fuzzyFields.add("billCode");
		fuzzyFields.add("projectName");
		fuzzyFields.add("bidUnitName");
		fuzzyFields.add("employeeName");

		param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

		/** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
		UserContext userContextCache = sessionManager.getUserContext();
		//当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
		String authOrgIds = userContextCache.getAuthOrgIds();
		List<OrgVO> orgVOList = null;
		if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
			orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
		} else {//pc端查询
			orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
		}
		//普通组织 id
		List<Long> commonOrgIds = new ArrayList<>();
		//项目部 id
		List<Long> departmentIds = new ArrayList<>();
		orgVOList.stream().forEach(org -> {
			if (5 == org.getOrgType()) {
				//项目部
				departmentIds.add(org.getId());
			} else {
				//普通组织
				commonOrgIds.add(org.getId());
			}
		});
		if (CollectionUtils.isNotEmpty(commonOrgIds)) {
			/** 要求主表有orgId字段，保存单据所属组织 */
			param.getParams().put("bid_unit_id", new Parameter(QueryParam.IN, commonOrgIds));
		}
		/** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

		IPage<RecordEntity> page = service.queryPage(param, false);
		IPage<RecordVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
		pageData.setRecords(BeanMapper.mapList(page.getRecords(), RecordVO.class));

		return CommonResponse.success("查询列表数据成功！", pageData);
	}

	/**
	 * 获取RPC数据
	 * resp 返回值
	 * isMustSuc 是否必须成功
	 * errMsg 失败提示
	 */
	private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
		if (isMustSuc && !resp.isSuccess()) {
			throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
		}
		return resp.getData();
	}


	/**
	 * @param param
	 *
	 * @Description 导出
	 * @Return void
	 */
	@PostMapping(value = "/excelExport")
	public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
		/** 模糊搜索配置字段示例 */
		List<String> fuzzyFields = param.getFuzzyFields();
		fuzzyFields.add("billCode");
		fuzzyFields.add("projectName");
		fuzzyFields.add("bidUnitName");
		fuzzyFields.add("employeeName");

		param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
		param.setPageIndex(1);
		param.setPageSize(-1);
		/** 数据隔离 本下 没有组织orgId的删除下面代码 */
		param.getParams().put("bid_unit_id", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
		List<RecordEntity> list = service.queryList(param);
		//todo:字段翻译等等
		Map<String, Object> beans = new HashMap<>();
		beans.put("records", list);
		ExcelExport.getInstance().export("Record-export.xlsx", beans, response);
	}

}

==> ejc-probid-impl-3.0.0-20220720.122230-28-sources.jar: com/ejianc/business/record/controller/RecordController.java <==
package com.ejianc.business.record.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.record.bean.RecordEntity;
import com.ejianc.business.record.service.IRecordService;
import com.ejianc.business.record.vo.RecordVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 工程投标备案实体
 *
 * @author generator
 */
@RestController
@RequestMapping("record")
public class RecordController implements Serializable {
	private static final long serialVersionUID = -8218768849910542504L;

	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	private static final String RULE_CODE = "PROBID_RECORD";
	private static final String BILL_CODE = "EJCBT202207000013";
	private final IBillTypeApi billTypeApi;
	private final IBillCodeApi billCodeApi;
	private final IOrgApi iOrgApi;
	private final IRecordService service;
	private final SessionManager sessionManager;

	public RecordController(IBillTypeApi billTypeApi, IBillCodeApi billCodeApi, IOrgApi iOrgApi, IRecordService service, SessionManager sessionManager) {
		this.billTypeApi = billTypeApi;
		this.billCodeApi = billCodeApi;
		this.iOrgApi = iOrgApi;
		this.service = service;
		this.sessionManager = sessionManager;
	}

	/**
	 * @Description saveOrUpdate 新增或者修改
	 */
	@PostMapping(value = "/saveOrUpdate")
	public CommonResponse<RecordVO> saveOrUpdate(@RequestBody RecordVO saveOrUpdateVO) {
		RecordEntity entity = BeanMapper.map(saveOrUpdateVO, RecordEntity.class);
		if (entity.getId() == null || entity.getId() == 0) {
			BillCodeParam billCodeParam = BillCodeParam.build(RULE_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
			CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
			if (billCode.isSuccess()) {
				entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
			} else {
				throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
			}
		}

		// 单据名称、单据类型
		entity.setBillName("工程投标备案表");
		entity.setBillType(BILL_CODE);
		entity.setBillStateName(BillStateEnum.UNCOMMITED_STATE.getDescription());

		service.saveOrUpdate(entity, false);
		RecordVO vo = BeanMapper.map(entity, RecordVO.class);
		return CommonResponse.success("保存或修改单据成功！", vo);
	}

	/**
	 * @param id
	 *
	 * @Description queryDetail 查询详情
	 */
	@GetMapping(value = "/queryDetail")
	public CommonResponse<RecordVO> queryDetail(Long id) {
		RecordEntity entity = service.selectById(id);
		RecordVO vo = BeanMapper.map(entity, RecordVO.class);
		return CommonResponse.success("查询详情数据成功！", vo);
	}

	/**
	 * @Description delete 批量删除单据
	 * @Param [ids]
	 */
	@PostMapping(value = "/delete")
	public CommonResponse<String> delete(@RequestBody List<RecordVO> vos) {
		if (ListUtil.isNotEmpty(vos)) {
			for (RecordVO vo : vos) {
				// 参数是单据类型编码字符串 根据需求是否打开下面代码
				CommonResponse<String> resp = billTypeApi.checkQuote(BILL_CODE, vo.getId());
				if (!resp.isSuccess()) {
					return CommonResponse.error("删除失败！" + resp.getMsg());
				}
			}
		}
		service.removeByIds(vos.stream().map(RecordVO::getId).collect(Collectors.toList()), true);
		return CommonResponse.success("删除成功！");
	}

	/**
	 * @param param
	 *
	 * @Description queryList 查询列表
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
	 */
	@PostMapping(value = "/queryList")
	public CommonResponse<IPage<RecordVO>> queryList(@RequestBody QueryParam param) {
		List<String> fuzzyFields = param.getFuzzyFields();
		fuzzyFields.add("billCode");
		fuzzyFields.add("projectName");
		fuzzyFields.add("bidUnitName");
		fuzzyFields.add("employeeName");

		param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

		param.getParams().put("bid_unit_id", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

		IPage<RecordEntity> page = service.queryPage(param, false);
		IPage<RecordVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
		pageData.setRecords(BeanMapper.mapList(page.getRecords(), RecordVO.class));

		return CommonResponse.success("查询列表数据成功！", pageData);
	}


	/**
	 * @param param
	 *
	 * @Description 导出
	 * @Return void
	 */
	@PostMapping(value = "/excelExport")
	public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
		List<String> fuzzyFields = param.getFuzzyFields();
		fuzzyFields.add("billCode");
		fuzzyFields.add("projectName");
		fuzzyFields.add("bidUnitName");
		fuzzyFields.add("employeeName");

		param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
		param.setPageIndex(1);
		param.setPageSize(-1);

		param.getParams().put("bid_unit_id", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

		IPage<RecordEntity> page = service.queryPage(param, false);
		List<RecordVO> records = new ArrayList<>();

		page.getRecords().forEach(e -> {
			RecordVO record = BeanMapper.map(e, RecordVO.class);
			record.setBillStateName(BillStateEnum.getEnumByStateCode(record.getBillState()).getDescription());
			records.add(record);
		});

		Map<String, Object> beans = new HashMap<>();
		beans.put("records", records);
		ExcelExport.getInstance().export("record-export.xlsx", beans, response);
	}


	/**
	 * 根据投标立项项目id查询工程投标备案记录
	 *
	 * @param projectId 投标立项项目id
	 *
	 * @return 工程投标备案记录
	 */
	@GetMapping(value = "/queryDetailByProjectId")
	public CommonResponse<RecordVO> queryDetailByProjectId(@RequestParam(value = "projectId") Long projectId) {
		return CommonResponse.success("查询详情数据成功！", service.queryDetailByProjectId(projectId));
	}

}
